mainwindow — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

# mainwindow

class `camelot.view.mainwindow.` `MainWindow`(app_admin, parent=None)

  Main window GUI

  `exportToExcel`()

    creates an excel file from the view

  `exportToWord`()

    Use windows COM to export the active child window to MS word, by using its to_html function

  `merge_document`()

    Run the merge document wizard on the selection in the current table view

  `updateMenus`()

    Toggle the status of the menus, depending on the active view

  `viewFirst`()

    selects view’s first row

  `viewLast`()

    selects view’s last row

  `viewNext`()

    selects view’s next row

  `viewPrevious`()

    selects view’s previous row

`camelot.view.mainwindow.` `addActions`(target, actions)

  add action objects to menus, menubars, and toolbars if action is None, add a separator.

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

Comments
blog comments powered by Disqus